@@ -26,9 +26,21 @@ class Decomposer:
         """
         if not isinstance(sequence, str):
             TypeError("Sequence must be a string")
+        if isinstance(motifs, str):
+            motifs = [motifs]  # only one string is given
         if not isinstance(motifs, list):
             TypeError("Motifs must be a list of strings")
 
+        sequence = sequence.upper()
+        motifs = [m.upper() for m in motifs]
+
+        if not is_valid_sequence(sequence):
+            raise ValueError(f"Sequence has invalid characters: {sequence}")
+
+        for motif in motifs:
+            if not is_valid_sequence(motif):
+                raise ValueError(f"The motif has invalid characters: {motif}")
+
         if self.mode == "DP":
             return self._decompose_dp(sequence, motifs, **kwargs)
         else:
@@ -45,9 +57,8 @@ class Decomposer:
 
         :param sequence: a string of VNTR sequence
         :param motifs: a list of motif strings composed of nucleotide strings
-
-        :param **kwargs: valids key words are
-
+        :param **kwargs:
+        valid keywords are the following:
         match_score: a score for match
         mismatch_score: a score for mismatch
         min_score_threshold: a minimum score of the alignment.
@@ -55,16 +66,6 @@ class Decomposer:
         :return: A list of decomposed motifs
         """
 
-        if not is_valid_sequence(sequence):
-            raise ValueError(f"Sequence has invalid characters: {sequence}")
-
-        if isinstance(motifs, str):
-            motifs = [motifs]  # only one string is given
-
-        for motif in motifs:
-            if not is_valid_sequence(motif):
-                raise ValueError("Consensus motif has invalid characters")
-
         """
         Let s[i,m,j] be the best parse of the sequence prefix s[1..i],
         where the i-th character is matched to the j-th character of motif m.
@@ -115,10 +116,10 @@ class Decomposer:
         _check_if_dp_parameters_are_valid(**kwargs)
 
         # Parameter setting
-        match_score = kwargs.get("match_score", 2)
-        mismatch_score = kwargs.get("mismatch_score", -1)
-        insertion_score = kwargs.get("insertion_score", -1)
-        deletion_score = kwargs.get("deletion_score", -1)
+        match_score = kwargs.get("match_score", 5)
+        mismatch_score = kwargs.get("mismatch_score", -4)
+        insertion_score = kwargs.get("insertion_score", -4)
+        deletion_score = kwargs.get("deletion_score", -4)
         min_score_threshold = kwargs.get("min_score_threshold", float("-inf"))
         verbose = kwargs.get("verbose", False)
 
@@ -390,13 +391,6 @@ class Decomposer:
         :return: A list of decomposed motifs
         """
 
-        if not is_valid_sequence(sequence):
-            raise ValueError("Sequence has invalid characters")
-
-        if consensus_motif is not None and not is_valid_sequence(consensus_motif):
-            raise ValueError("Consensus motif has invalid characters")
-
-
         def _check_if_hmm_parameters_are_valid(**kwargs):
             valid_keys = {"repeat_count", "has_flanking_sequence", "verbose"}
             for k, v in kwargs.items():
