@@ -47,9 +47,18 @@ class TandemRepeatVisualizer:
         if box_margin < 0 or box_margin > box_size:
             raise ValueError(f"Box margin should be between 0 and {box_size}.")
 
-        fig, ax = plt.subplots()
+        if symbol_to_color is None:
+            raise ValueError("Symbol to color is not set.")
+
         if figure_size is not None:
             fig, ax = plt.subplots(figsize=figure_size)
+        else:
+            max_motif_length = len(max(symbol_to_motif.values(), key=len))
+            w = len(symbol_to_motif) // 10 + 5 if len(symbol_to_motif) > 50 else len(symbol_to_motif) // 5 + 1
+            h = max_motif_length // 10 + max_motif_length if max_motif_length > 50 else max_motif_length // 5 + 1
+            if h * dpi > 2 ** 16:
+                h = 2 ** 15 // dpi * 0.75  # "Weight and Height must be less than 2^16"
+            fig, ax = plt.subplots(figsize=(w, h))
         ax.set_aspect('equal')
 
         max_motif_length = len(max(symbol_to_motif.values(), key=len))
@@ -57,8 +66,10 @@ class TandemRepeatVisualizer:
         # TODO: figure and font size
         yticklabels = []
         y_base_position = 0
+        has_gap_in_symbol_to_color = False
         for (symbol, color) in symbol_to_color.items():
             if symbol == '-':
+                has_gap_in_symbol_to_color = True
                 continue
             box_position = [box_margin, y_base_position + box_margin]
             box_width = box_size - 2 * box_margin
@@ -77,7 +88,10 @@ class TandemRepeatVisualizer:
 
         ax.yaxis.tick_right()
         ax.set_ylim(top=len(symbol_to_color) - 1)
-        ax.set_yticks([y * box_size + box_size*0.5 for y in range(len(symbol_to_color) - 1)])  # minus 1 for gap, '-'
+        yticks_count = len(symbol_to_color)
+        if has_gap_in_symbol_to_color:
+            yticks_count = len(symbol_to_color) - 1
+        ax.set_yticks([y * box_size + box_size*0.5 for y in range(yticks_count)])  # minus 1 for gap, '-'
         ax.set_yticklabels(yticklabels)
 
         # font size
@@ -110,7 +124,7 @@ class TandemRepeatVisualizer:
 
     def trplot(self,
                aligned_labeled_repeats: List[str],
-               sample_ids: List[str] = None,
+               sample_ids: List[str],
                figure_size: Tuple[int, int] = None,
                output_name: str = None,
                dpi: int = 500,
@@ -161,14 +175,21 @@ class TandemRepeatVisualizer:
 
         # Add clustering
         if sort_by_clustering:
-            if debug:
-                print("Sort by clustering")
+            if symbol_to_motif is None:
+                raise ValueError("symbol_to_motif must be provided when sort_by_clustering is True")
+
             sorted_sample_ids, sorted_aligned_labeled_repeats = self.add_dendrogram(fig,
                                                                                     aligned_labeled_repeats,
                                                                                     sample_ids,
                                                                                     symbol_to_motif,
                                                                                     hide_dendrogram)
+            if debug:
+                print("Sort by clustering")
+                print('\n'.join(sorted_sample_ids))
+
         else:
+            # Already sorted in some way
+            sorted_sample_ids, sorted_aligned_labeled_repeats = sample_ids, aligned_labeled_repeats
             if debug:
                 print("No clustering")
 
@@ -259,7 +280,7 @@ class TandemRepeatVisualizer:
             # if re.match(".*", tweet):
             #     fig.savefig(f"{output_name}", dpi=dpi, bbox_inches='tight')
             # else:
-            fig.savefig(f"{output_name}.png", dpi=800, bbox_inches='tight')
+            fig.savefig(f"{output_name}.pdf", dpi=800, bbox_inches='tight')
         else:
             fig.savefig("test_trplot.png", dpi=dpi, bbox_inches='tight')
 
